/*************************************************************************
/* FieldPositions12.java -- Test parameters for java.text.FieldPosition
/*
/* Copyright (c) 2003 Free Software Foundation, Inc.
/* Written by Dalibor Topic <robilad@kaffe.org>
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published 
/* by the Free Software Foundation, either version 2 of the License, or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; if not, write to the Free Software Foundation
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA
/*************************************************************************/

// Tags: not-a-test
// Uses: TestParameters11

package gnu.testlet.java.text.FieldPosition;

import java.text.FieldPosition;

/**
 * A utility class for instances of test parameters that are used 
 * for JDK 1.2 API testing.
 *
 * @author <a href="mailto:topic@mpi-sb.mpg.de">Dalibor Topic</a>
 * @version 1.0
 */
public class FieldPositions12 extends FieldPositions11 {

  /**
   * Total number of test cases.
   *
   * Computed by mutliplying the number of distinct interesting 
   * options for each settable field.
   *
   * PARAMS.length for field, which is set through constructor
   * times 
   * PARAMS.length for beginIndex, which is set through setter method
   * times 
   * PARAMS.length for endIndex, which is set through setter method
   */
  private static final int NUMBER_OF_TESTCASES =
   TestParameters.getInts().length
    * TestParameters.getInts().length
    * TestParameters.getInts().length;

  /**
   * Initialize instances for testing.
   *
   * @param fixtures array of fixtures to initialize
   */
  private void initFixtures(final FieldPosition [] fixtures) {

    final int [] params =  TestParameters.getInts();

    /* Create FieldPosition instances for testing. */
    for (int i = 0; i < params.length; ++i) {
      for (int j = 0; j < params.length; ++j) {
	for (int k = 0; k < params.length; ++k) {
	  /* Pick the index of FieldPosition to initialize */
	  final int index = 
	    i * params.length * params.length
	    + j * params.length 
	    + k;

	  /* Set the field values. */
	  fixtures[index] = new FieldPosition(params[i]);
	  FieldPosition x = fixtures[index];

	  x.setBeginIndex(j);
	  x.setEndIndex(k);
	}
      }
    }
  }

  /**
   * Return all available fixtures in a virgin state.
   *
   * @return a <code>FieldPosition[]</code> of test instances
   */
  public Object [] getAllFixtures()
  {

    /* Array of tested FieldPostions. */
    final FieldPosition [] fps = 
      new FieldPosition [NUMBER_OF_TESTCASES];

    initFixtures(fps);

    return fps;
  }
} // class FieldPositions12
