/*************************************************************************
/* equals.java -- Test java.lang.Object equals(Object)
/*
/* Copyright (c) 2003 Free Software Foundation, Inc.
/* Written by Dalibor Topic <robilad@kaffe.org>
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published 
/* by the Free Software Foundation, either version 2 of the License, or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; if not, write to the Free Software Foundation
/* Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307 USA
/*************************************************************************/

// Tags: not-a-test
// Uses: TestFixture

package gnu.testlet.java.text.FieldPosition;

import gnu.testlet.TestHarness;

/**
 *  Test behaviour of <code>equals(Object)</code> method.
 *
 * @author <a href="mailto:robilad@kaffe.org">Dalibor Topic</a>
 * @version 1.0
 */
public class equals
{
  /**
   * Test if x.equals(null) is false.
   *
   * @param harness a <code>TestHarness</code>
   * @param instances an <code>Object[]</code> of instances to test
   */
  private static void testNull(TestHarness harness, Object [] instances)
  {
    harness.checkPoint("equals: null");

    for (int i = 0; i < instances.length; ++i) {
      final Object x = instances[i];

      harness.check(!x.equals(null));
      
      harness.debug("x=" + x.toString());
    }
  }    

  /**
   * Test if x.equals(x) is true.
   *
   * @param harness a <code>TestHarness</code>
   * @param instances an <code>Object[]</code> of instances to test
   */
  private static void testReflexivity(TestHarness harness, Object [] instances)
  {
    harness.checkPoint("equals: reflexivity");

    for (int i = 0; i < instances.length; ++i) {
      final Object x = instances[i];

      harness.check(x.equals(x));

      harness.debug("x=" + x.toString());
    }
  }

  /**
   * Test if x.equals(y) iff. y.equals(x).
   *
   * @param harness a <code>TestHarness</code>
   * @param instances an <code>Object[]</code> of instances to test
   */
  private static void testSymmetry(TestHarness harness, Object [] instances)
  {
    harness.checkPoint("equals: symmetry");

    for (int i = 0; i < instances.length; ++i) {
      for (int j = 0; j < instances.length; ++j) {
	final Object x = instances[i];
	final Object y = instances[j];

	if (x.equals(y))
	  harness.check(y.equals(x));
	else
	  harness.check(!y.equals(x));

	harness.debug("x=" + x.toString()
		      + ",y=" + y.toString());
      }
    }
  }

  /**
   * Test if x.equals(z) when x.equals(y) and y.equals(z).
   *
   * @param harness a <code>TestHarness</code>
   * @param instances an <code>Object[]</code> of instances to test
   */
  private static void testTransitivity(TestHarness harness, Object [] instances)
  {
    harness.checkPoint("equals: transitivity");

    for (int i = 0; i < instances.length; ++i) {
      for (int j = 0; j < instances.length; ++j) {
	for (int k = 0; k < instances.length; ++k) {
	  final Object x = instances[i];
	  final Object y = instances[j];
	  final Object z = instances[k];

	  if (x.equals(y) && y.equals(z))
	    harness.check(x.equals(z));

	  harness.debug("x=" + x.toString()
			+ ",y=" + y.toString()
			+ ",z=" + z.toString());
	}
      }
    }
  }

  /**
   * Test the behaviour of the method.
   *
   * @param harness a <code>TestHarness</code>
   * @param fixture a <code>TestFixture</code>
   */
  public static void test(TestHarness harness, TestFixture fixture)
  {
    testNull(harness, fixture.getAllFixtures());
    testReflexivity(harness, fixture.getAllFixtures());
    testSymmetry(harness, fixture.getAllFixtures());
    testTransitivity(harness, fixture.getAllFixtures());
  }

} // class equals
